/******************************************************************************
 * Copyright © 2007  Red Hat, Inc. All rights reserved.
 *
 *This copyrighted material is made available to anyone wishing to use, modify,
 *copy, or redistribute it subject to the terms and conditions of the GNU 
 *General Public License v.2.  This program is distributed in the hope that it
 *will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
 *implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *See the GNU General Public License for more details.  You should have received
 *a copy of the GNU General Public License along with this program; if not,
 *write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *Boston, MA 02110-1301, USA. Any Red Hat trademarks that are incorporated in
 *the source code or documentation are not subject to the GNU General Public
 *License and may only be used or replicated with the express permission of
 *Red Hat, Inc.
 *
 *Red Hat Author(s): 	Alex Larsson
 *			Jeff Moyer
 *			Michael K Johnson
 *			Elliot Le
 *			Neil Horman 
 ******************************************************************************/
#ifndef NETDUMPCLIENT_H
#define NETDUMPCLIENT_H

#include <glib.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include "netconsole.h"

typedef struct _NetdumpClient NetdumpClient;

#define MAGIC_SIZE 8

#define IP_ADDR_SIZE 16  /* "255:255:255:255\0" */

typedef struct {
  guint32 page_nr;
  char   *data;
  guint32 sections_received;
  guint32 request_nr;
  guint   n_timeouts;
  guint   timeout_tag;
  guint   timeout_delay;
} OutstandingPage;

struct _NetdumpClient {
  guint32 ip;
  guint16 port;
  gboolean just_reboot;
  
  guint32 outstanding_request;
  guint   timeout_tag;
  guint   n_timeouts;
  guint   n_handshakes;
  guint   timeout_delay;

  gboolean got_log_packet;
  
  unsigned char magic_value[MAGIC_SIZE];
  
  /* Host data */
  guint32 nr_pages;  /* max page frame number */
  guint32 page_size;
  guint64 page_offset;

  /* Version 5 additions */
  u32 effective_version;
  u32 machine_type;
  u32 totalram_pages;
  u32 next_avail_page;
  u64 task_struct;
  u64 netdump_magic;
  unsigned char ip_addr[IP_ADDR_SIZE]; /* for syslog strings only */

  gchar  *regs;
  guint   regs_len;
  
  guint32 current_page;
  OutstandingPage *outstanding;
  int     n_outstanding;
  
  void (*timeout)        (NetdumpClient *client,
			  guint32        request_nr);
  void (*process_packet) (NetdumpClient *client,
			  struct sockaddr_in *addr,
			  unsigned char *buffer,
			  int buf_len);


  /* Coredump data: */
  int    dump_fd;
  size_t data_offset;

  char *dump_dir;

  u32 flags;
  void *elf_header_mmap;
  void *pt_load_ptr;
  int current_pt_load;
  int load_segments;
};

#define MULTIPLE_PT_LOADS (0x1)

#define HOLE_SIZE (256)


NetdumpClient *netdump_client_new     (guint32        ip,
				       guint16        port,
				       const char    *dir,
				       const char     magic[MAGIC_SIZE],
				       gboolean       just_reboot,
				       reply_t 	     *reply,
				       char          *msg);
void           netdump_client_destroy (NetdumpClient *client,
				       int reboot);
guint          netdump_client_hash    (gconstpointer  key);
gint           netdump_client_compare (gconstpointer  a,
				       gconstpointer  b);


#endif
